@@ -1,4 +1,4 @@
-# Copyright (c) 2015-2021 Matthias Geier
+# Copyright (c) 2015-2022 Matthias Geier
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -23,11 +23,12 @@
 https://nbsphinx.readthedocs.io/
 
 """
-__version__ = '0.8.9'
+__version__ = '0.8.10'
 
 import collections.abc
 import copy
 import html
+from itertools import chain
 import json
 import os
 import re
@@ -299,6 +300,15 @@ RST_TEMPLATE = """
 """.replace('__RST_DEFAULT_TEMPLATE__', nbconvert.RSTExporter().template_file)
 
 
+# MEMO: the nbsphinxfancyoutput environment recycles some internal Sphinx
+# LaTeX macros, as testify the @ in their names.  At 5.1.0 these macros
+# got modified so we now have two cases for the nbsphinxfancyoutput
+# definition: Sphinx >= 5.1.0 or Sphinx < 5.1.0 (and >= 1.7.0 at least).
+
+# MEMO: since Sphinx 2.0 the upstream \sphinxincludegraphics is similar and
+# slightly better than the \nbsphinxincludegraphics defined here.  So for the
+# >= 5.1.0 branch of nbsphinxfancyoutput, the code does no replacement of
+# \sphinxincludegraphics by \nbsphinxincludegraphics anymore.
 LATEX_PREAMBLE = r"""
 % Jupyter Notebook code cell colors
 \definecolor{nbsphinxin}{HTML}{307FC1}
@@ -327,7 +337,39 @@ LATEX_PREAMBLE = r"""
 \definecolor{ansi-default-inverse-bg}{HTML}{000000}
 
 % Define an environment for non-plain-text code cell outputs (e.g. images)
+\newbox\nbsphinxpromptbox
 \makeatletter
+\@ifpackagelater{sphinx}{2022/06/30}{% "later" means here "at least"
+% In this branch Sphinx is at least at 5.1.0
+\newenvironment{nbsphinxfancyoutput}{%
+\sphinxcolorlet{VerbatimColor}{white}%
+\sphinxcolorlet{VerbatimBorderColor}{nbsphinx-code-border}%
+\spx@verb@boxes@fcolorbox@setup
+    % for \sphinxincludegraphics check of maximal height
+    \spx@image@maxheight         \textheight
+    \advance\spx@image@maxheight -\spx@boxes@border@top
+    \advance\spx@image@maxheight -\spx@boxes@padding@top
+    \advance\spx@image@maxheight -\spx@boxes@padding@bottom
+    \advance\spx@image@maxheight -\spx@boxes@border@bottom
+    \advance\spx@image@maxheight -\baselineskip
+\def\sphinxVerbatim@Before{\nbsphinxfancyaddprompt}%
+\def\sphinxVerbatim@After {\@empty}%
+\def\FrameCommand     {\sphinxVerbatim@FrameCommand}%
+\def\FirstFrameCommand{\sphinxVerbatim@FirstFrameCommand}%
+\def\MidFrameCommand  {\sphinxVerbatim@MidFrameCommand}%
+\def\LastFrameCommand {\sphinxVerbatim@LastFrameCommand}%
+\MakeFramed{\advance\hsize-\width\@totalleftmargin\z@\linewidth\hsize\@setminipage}%
+\lineskip=1ex\lineskiplimit=1ex\raggedright%
+}{\par\unskip\@minipagefalse\endMakeFramed}
+\def\nbsphinxfancyaddprompt{\ifvoid\nbsphinxpromptbox\else
+    \kern\spx@boxes@border@top\kern\spx@boxes@padding@top
+    \copy\nbsphinxpromptbox
+    \kern-\ht\nbsphinxpromptbox\kern-\dp\nbsphinxpromptbox
+    \kern-\spx@boxes@padding@top\kern-\spx@boxes@border@top
+    \nointerlineskip
+    \fi}
+}% End of Sphinx >= 5.1.0 branch
+{% This branch for Sphinx < 5.1.0
 \newenvironment{nbsphinxfancyoutput}{%
     % Avoid fatal error with framed.sty if graphics too long to fit on one page
     \let\sphinxincludegraphics\nbsphinxincludegraphics
@@ -343,14 +385,14 @@ LATEX_PREAMBLE = r"""
 \MakeFramed{\advance\hsize-\width\@totalleftmargin\z@\linewidth\hsize\@setminipage}%
 \lineskip=1ex\lineskiplimit=1ex\raggedright%
 }{\par\unskip\@minipagefalse\endMakeFramed}
-\makeatother
-\newbox\nbsphinxpromptbox
 \def\nbsphinxfancyaddprompt{\ifvoid\nbsphinxpromptbox\else
     \kern\fboxrule\kern\fboxsep
     \copy\nbsphinxpromptbox
     \kern-\ht\nbsphinxpromptbox\kern-\dp\nbsphinxpromptbox
     \kern-\fboxsep\kern-\fboxrule\nointerlineskip
     \fi}
+}% end of Sphinx < 5.1.0 branch
+\makeatother
 \newlength\nbsphinxcodecellspacing
 \setlength{\nbsphinxcodecellspacing}{0pt}
 
@@ -404,6 +446,8 @@ LATEX_PREAMBLE = r"""
 }% end of \nbsphinxstopnotebook
 
 % Ensure height of an included graphics fits in nbsphinxfancyoutput frame
+% The Sphinx >= 5.1.0 version of nbsphinxfancyoutput does not use this macro
+% as \sphinxincludegraphics is since Sphinx 2.0 similar and slightly better.
 \newdimen\nbsphinx@image@maxheight % set in nbsphinxfancyoutput environment
 \newcommand*{\nbsphinxincludegraphics}[2][]{%
     \gdef\spx@includegraphics@options{#1}%
@@ -551,10 +595,11 @@ div.nboutput.container div.prompt > div {
     }
 }
 
-/* disable scrollbars on prompts */
+/* disable scrollbars and line breaks on prompts */
 div.nbinput.container div.prompt pre,
 div.nboutput.container div.prompt pre {
     overflow: hidden;
+    white-space: pre;
 }
 
 /* input/output area */
@@ -1886,10 +1931,14 @@ def patched_toctree_resolve(self, docname, builder, toctree, *args, **kwargs):
 
 
 def config_inited(app, config):
-    if '.ipynb' not in config.source_suffix:
-        app.add_source_suffix('.ipynb', 'jupyter_notebook')
     for suffix in config.nbsphinx_custom_formats:
         app.add_source_suffix(suffix, 'jupyter_notebook')
+    if '.ipynb' in chain(config.source_suffix, app.registry.source_suffix):
+        # We don't interfere if '.ipynb' has been added by the user in conf.py
+        # or by another Sphinx extension that has been loaded earlier.
+        pass
+    else:
+        app.add_source_suffix('.ipynb', 'jupyter_notebook')
 
     if '**.ipynb_checkpoints' not in config.exclude_patterns:
         config.exclude_patterns.append('**.ipynb_checkpoints')
